@@ -68,10 +68,19 @@ from vessl.kernel_resource_spec import (
 )
 from vessl.model import (
     create_model,
+    create_model_repository,
     delete_model,
+    delete_model_repository,
+    delete_model_volume_file,
+    download_model_volume_file,
+    list_model_repositories,
+    list_model_volume_files,
     list_models,
     read_model,
+    read_model_repository,
     update_model,
+    update_model_repository,
+    upload_model_volume_file,
 )
 from vessl.organization import (
     create_organization,
@@ -82,6 +91,7 @@ from vessl.project import create_project, list_projects, read_project
 from vessl.ssh_key import create_ssh_key, delete_ssh_key, list_ssh_keys
 from vessl.sweep import (
     create_sweep,
+    get_best_sweep_experiment,
     list_sweep_logs,
     list_sweeps,
     read_sweep,
@@ -106,6 +116,9 @@ from vessl.workspace import (
 # Expose others
 from vessl.util.image import Image  # isort:skip
 from vessl.util.audio import Audio  # isort:skip
+from openapi_client.models import OrmSweepObjective as SweepObjective  # isort:skip
+from openapi_client.models import OrmParameter as SweepParameter  # isort:skip
+from openapi_client.models import OrmRange as SweepParameterRange  # isort:skip
 
 
 # Suppress all exceptions during SDK mode
@@ -133,7 +146,7 @@ for name, value in inspect.getmembers(
     vars()[name] = suppress_sdk_exception(value)
 
 # Other classes that the user may interact with
-user_classes = [Image, Audio]
+user_classes = [Image, Audio, SweepObjective, SweepParameter, SweepParameterRange]
 for user_class in user_classes:
     for name, value in inspect.getmembers(
         user_class, predicate=lambda x: inspect.ismethod(x) or inspect.isfunction(x)
