@@ -66,9 +66,7 @@ def prompt_organizations() -> str:
 
     if choice == organization_count:
         organization_name = click.prompt("Organization name", type=click.STRING)
-        regions = vessl.vessl_api.region_list_api().regions
-        region = prompt_choices("Region", [(x.name, x.value) for x in regions])
-        vessl.create_organization(organization_name, region)
+        vessl.create_organization(organization_name)
     else:
         organization_name = organizations[choice].name
 
