@@ -3,7 +3,7 @@ from typing import List
 
 import click
 
-from openapi_client import ResponseSimpleModelDetail
+from openapi_client import ResponseSimpleModelInfo
 from vessl import list_experiment_output_files, list_experiments
 from vessl.cli._base import VesslGroup, vessl_argument, vessl_option
 from vessl.cli._util import (
@@ -37,14 +37,14 @@ from vessl.model import (
 from vessl.util.constant import MODEL_SOURCE_EXPERIMENT, MODEL_SOURCE_LOCAL
 
 
-def model_repository_status(latest_model: ResponseSimpleModelDetail) -> str:
+def model_repository_status(latest_model: ResponseSimpleModelInfo) -> str:
     if latest_model:
         return latest_model.status
     return "Empty repository"
 
 
 def model_repository_update_dt(
-    latest_model: ResponseSimpleModelDetail, default: datetime
+    latest_model: ResponseSimpleModelInfo, default: datetime
 ) -> datetime:
     if latest_model:
         return truncate_datetime(latest_model.created_dt)
