@@ -72,9 +72,8 @@ def list():
     required=True,
     prompter=generic_prompter("Organization name"),
 )
-@vessl_argument("region", type=click.STRING, required=True, prompter=region_prompter)
-def create(name: str, region: str):
-    organization = create_organization(organization_name=name, region=region)
+def create(name: str):
+    organization = create_organization(organization_name=name)
     print(
         f"Created '{organization.name}'.\n"
         f"For more info: {Endpoint.organization.format(organization.name)}"
