@@ -2,6 +2,7 @@ from typing import Any, Dict, List, Tuple
 
 import click
 
+from openapi_client import OrmParameter, OrmSweepObjective
 from vessl.cli._base import VesslGroup, vessl_argument, vessl_option
 from vessl.cli._util import (
     Endpoint,
@@ -20,11 +21,11 @@ from vessl.cli.experiment import (
     command_option,
     cpu_limit_option,
     dataset_option,
-    env_var_option,
     git_diff_option,
     git_ref_option,
     gpu_limit_option,
     gpu_type_option,
+    hyperparameter_option,
     image_url_option,
     memory_limit_option,
     message_option,
@@ -38,6 +39,7 @@ from vessl.cli.organization import organization_name_option
 from vessl.cli.project import project_name_option
 from vessl.sweep import (
     create_sweep,
+    get_best_sweep_experiment,
     list_sweep_logs,
     list_sweeps,
     read_sweep,
@@ -79,17 +81,19 @@ class SweepParameterType(click.ParamType):
             parameter["range"] = {"list": values}
             return parameter
 
-        if len(values) < 3:
+        if len(values) < 2:
             raise click.BadOptionUsage(
                 option_name="parameter",
-                message=f"Invalid value for [PARAMETER]: range type '{SWEEP_PARAMETER_RANGE_TYPE_SPACE}' must have min, max, step values.",
+                message=f"Invalid value for [PARAMETER]: range type '{SWEEP_PARAMETER_RANGE_TYPE_SPACE}' must have min and max values.",
             )
 
         parameter["range"] = {
             "min": values[0],
             "max": values[1],
-            "step": values[2],
         }
+        if len(values) >= 3:
+            parameter["range"]["step"] = values[2]
+
         return parameter
 
 
@@ -140,7 +144,6 @@ def read(name: str):
             "Status": sweep.status,
             "Created": truncate_datetime(sweep.created_dt),
             "Message": format_string(sweep.message),
-            "Source Code": sweep.source_code_link[0].url,
             "Objective": (
                 f"{sweep.objective.type}"
                 f"{' > ' if sweep.objective.metric == SWEEP_OBJECTIVE_TYPE_MAXIMIZE else ' < '}"
@@ -215,13 +218,6 @@ def list():
     required=True,
     prompter=choices_prompter("Objective type", SWEEP_OBJECTIVE_TYPES),
 )
-@vessl_option(
-    "-G",
-    "--objective-goal",
-    type=click.FLOAT,
-    required=True,
-    prompter=generic_prompter("Objective goal", click.FLOAT),
-)
 @vessl_option(
     "-M",
     "--objective-metric",
@@ -229,6 +225,13 @@ def list():
     required=True,
     prompter=generic_prompter("Objective metric", click.STRING),
 )
+@vessl_option(
+    "-G",
+    "--objective-goal",
+    type=click.STRING,
+    required=True,
+    prompter=generic_prompter("Objective goal", click.FLOAT),
+)
 @vessl_option(
     "--num-experiments",
     type=click.INT,
@@ -269,7 +272,6 @@ def list():
     help="Search space parameters (at least one required). Format: [name] [type] [range type] [values...], ex. `-p epochs int space 5 10 15 20`.",
 )
 @cluster_option
-@command_option
 @resource_option
 @processor_type_option
 @cpu_limit_option
@@ -277,6 +279,8 @@ def list():
 @gpu_type_option
 @gpu_limit_option
 @image_url_option
+@hyperparameter_option
+@command_option
 @vessl_option("--early-stopping-name", type=str, help="Early stopping algorithm name.")
 @vessl_option(
     "--early-stopping-settings",
@@ -285,7 +289,6 @@ def list():
     help="Early stopping algorithm settings. Format: [key] [value], ex. `--early-stopping-settings start_step 4`.",
 )
 @message_option
-@env_var_option
 @dataset_option
 @git_ref_option
 @git_diff_option
@@ -307,7 +310,7 @@ def create(
     cluster: str,
     command: str,
     resource: str,
-    processor: str,
+    processor_type: str,
     cpu_limit: float,
     memory_limit: float,
     gpu_type: str,
@@ -316,7 +319,7 @@ def create(
     early_stopping_name: str,
     early_stopping_settings: List[Tuple[str, str]],
     message: str,
-    env_var: List[Tuple[str, str]],
+    hyperparameter: List[Tuple[str, str]],
     dataset: List[str],
     git_ref: List[str],
     git_diff: str,
@@ -326,18 +329,23 @@ def create(
     output_dir: str,
 ):
     sweep = create_sweep(
-        objective_type=objective_type,
-        objective_goal=objective_goal,
-        objective_metric=objective_metric,
+        objective=OrmSweepObjective(
+            type=objective_type,
+            goal=objective_goal,
+            metric=objective_metric,
+        ),
         max_experiment_count=num_experiments,
         parallel_experiment_count=num_parallel,
         max_failed_experiment_count=num_failed,
         algorithm=algorithm,
-        parameters=parameter,
+        parameters=[
+            OrmParameter(name=p.get("name"), type=p.get("type"), range=p.get("range"))
+            for p in parameter
+        ],
         cluster_name=cluster,
         start_command=command,
         kernel_resource_spec_name=resource,
-        processor_type=processor,
+        processor_type=processor_type,
         cpu_limit=cpu_limit,
         memory_limit=memory_limit,
         gpu_type=gpu_type,
@@ -346,7 +354,7 @@ def create(
         early_stopping_name=early_stopping_name,
         early_stopping_settings=early_stopping_settings,
         message=message,
-        env_vars=env_var,
+        hyperparameters=hyperparameter,
         dataset_mounts=dataset,
         git_ref_mounts=git_ref,
         git_diff_mount=git_diff,
@@ -387,3 +395,31 @@ def logs(name: str, tail: int):
     logs = list_sweep_logs(sweep_name=name, limit=tail)
     print_logs(logs)
     print(f"Displayed last {len(logs)} lines of '{name}'.")
+
+
+@cli.vessl_command()
+@vessl_argument("name", type=click.STRING, required=True, prompter=sweep_name_prompter)
+@organization_name_option
+@project_name_option
+def best_experiment(name: str):
+    experiment = get_best_sweep_experiment(sweep_name=name)
+    if not experiment.initialized_dt:
+        print("No experiments in sweep.")
+        return
+
+    print_data(
+        {
+            "Experiment number": experiment.experiment_number,
+            "Objective": {
+                "Metric name": experiment.objective_metric_name,
+                "Metric value": experiment.objective_metric_value,
+            },
+            "Parameters": [
+                {
+                    "Name": x.name,
+                    "Value": x.value,
+                }
+                for x in experiment.parameters
+            ],
+        }
+    )
