@@ -414,7 +414,8 @@ class VesslRun(object):
         path_to_caption = {}
         for media in payload.values():
             for medium in media:
-                path_to_caption[medium.path] = medium.caption
+                path = os.path.basename(medium.path)
+                path_to_caption[path] = medium.caption
                 if not set_media_type:
                     if not isinstance(medium, Image) and not isinstance(medium, Audio):
                         raise InvalidTypeError(
@@ -431,7 +432,6 @@ class VesslRun(object):
             source_path=os.path.join(VESSL_MEDIA_PATH, ""),
             dest_volume_id=self._experiment.experiment_plot_volume,
             dest_path="/",
-            recursive=True,
         )
 
         for media in payload.values():
