@@ -30,7 +30,7 @@ from vessl.util.exception import (
     InvalidTokenError,
     VesslApiException,
 )
-from vessl.util.git_repo import GitRepository
+from vessl.util.git_local_repo import GitRepository
 
 
 def raise_vessl_exception(f):
@@ -45,6 +45,8 @@ def raise_vessl_exception(f):
 
 
 class VesslApi(APIV1Api):
+    """VESSL Client API"""
+
     def __init__(self, *, api_host=API_HOST, **kwargs):
         _api_configuration = Configuration(host=api_host)
         # Disable verify ssl (https://github.com/urllib3/urllib3/issues/1682#issuecomment-533311857) # noqa E501
@@ -90,6 +92,24 @@ class VesslApi(APIV1Api):
         credentials_file: str = None,
         force_update_access_token: bool = False,
     ) -> None:
+        """Configure VESSL Client API.
+
+        Args:
+            access_token(str): Access token to override. Defaults to
+                `access_token` from `~/.vessl/config`.
+            organization_name(str): Organization name to override. Defaults to
+                `organization_name` from `~/.vessl/config`.
+            project_name(str): Project name to override. Defaults to
+                `project name` from `~/.vessl/config`.
+            credentials_file(str): Defaults to None.
+            force_update_access_token(bool): True if force update access token,
+                False otherwise. Defaults to False.
+
+        Example:
+            ```python
+            vessl.configure()
+            ```
+        """
         self.configure_access_token(
             access_token, credentials_file, force_update_access_token
         )
@@ -293,3 +313,15 @@ class VesslApi(APIV1Api):
     ) -> None:
         project_name = self.set_project(project_name, credentials_file)
         self.config_loader.default_project = project_name
+
+    def set_configurations(
+        self,
+        access_token: str = None,
+        organization_name: str = None,
+        project_name: str = None,
+        credentials_file: str = None,
+    ):
+        """ Used in vessl.init() """
+        self.set_access_token(access_token, credentials_file)
+        self.set_organization(organization_name, credentials_file)
+        self.set_project(project_name, credentials_file)
